pub struct WrapperChrono {
pub time: i64,
}Fields
time: i64Implementations
Sourceimpl WrapperChrono
impl WrapperChrono
pub fn get_mut_time(&mut self) -> &mut i64
pub fn from_json(json_value: Value) -> Result<Self, String>
pub fn to_json(&self) -> Value
pub fn new<'a>(time: i64) -> Self
Sourcepub fn get_time(&self) -> &i64
pub fn get_time(&self) -> &i64
Get an immutable reference to the {field_name} field of the struct.
This method allows you to obtain an immutable reference to the {field_name}
field of the struct, which you can use to access its value.
Returns
An immutable reference to the {field_name} field.
Sourcepub fn set_time<T: Into<i64>>(&mut self, new: T)
pub fn set_time<T: Into<i64>>(&mut self, new: T)
Set the value of the {field_name} field of the struct.
This method allows you to update the value of the {field_name} field of the struct.
Arguments
new: A value of type that can be converted into{field_name}’s type.
Sourcepub fn print_all_levels(&self)
pub fn print_all_levels(&self)
Print the struct with various labels and color-coded output.
Sourcepub fn print_rust(&self)
pub fn print_rust(&self)
Print the struct with a ‘RUST’ label and dark red color-coded output.
Sourcepub fn print_info(&self)
pub fn print_info(&self)
Print the struct with an ‘INFO’ label and purple color-coded output.
Sourcepub fn print_success(&self)
pub fn print_success(&self)
Print the struct with a ‘SUCCESS’ label and light green color-coded output.
Sourcepub fn print_warning(&self)
pub fn print_warning(&self)
Print the struct with a ‘WARNING’ label and light yellow color-coded output.
Sourcepub fn print_success_time(&self)
pub fn print_success_time(&self)
Print the value of the {field_name} field with a ‘SUCCESS’ label and light yellow color-coded output.
Sourcepub fn print_time(&self)
pub fn print_time(&self)
Print the value of the {field_name} field with a default label and light yellow color-coded output.
Sourcepub fn print_rust_time(&self)
pub fn print_rust_time(&self)
Print the value of the {field_name} field with a ‘RUST’ label and light yellow color-coded output.
Sourcepub fn print_info_time(&self)
pub fn print_info_time(&self)
Print the value of the {field_name} field with a ‘INFO’ label and light yellow color-coded output.
Sourcepub fn print_warning_time(&self)
pub fn print_warning_time(&self)
Print the value of the {field_name} field with a ‘WARNING’ label and light yellow color-coded output.
Sourcepub fn print_err_time(&self)
pub fn print_err_time(&self)
Print the value of the {field_name} field with a ‘ERR’ label and light yellow color-coded output.